Enum SendingResult

pub enum SendingResult {
    Sent,
    WeClosed,
    PeerClosedOrDied,
    Error,
}
Was the message successfully sent, or did it fail (and why)?

Variants



Sent

The message was sent with success!



WeClosed

We (ourselves, not the peer) closed the connection before the message was entirely sent.



PeerClosedOrDied

The peer closed the connection (either intentionally or due to a panic/crash/shutdown) before the message was entirely received.



Error

An error occured which prevented the sending of the message.

Implementations

Source

impl SendingResult

pub fn sent(&self) -> bool

Has the message been successfully sent?

pub fn failed_due_to_connection_closed(&self) -> bool

Has the message failed to be sent due to the connection being closed?

Ignoring such situation might be appropriate.

pub fn failed_due_to_error(&self) -> bool

Has the message failed to be sent due to some error (and not due to the connection being closed)?