Enum SendingState

pub enum SendingState {
    StillBeingSent(SendingStateHandle),
    Result(SendingResult),
}
Has the message finished being sent? With what SendingResult?

Variants



StillBeingSent(SendingStateHandle)

The message is still in the process of being sent. It will finish being sent (or fail) later. The SendingStateHandle used to get this sending state is given back to try again later.



Result(SendingResult)

The message is not being sent anymore. It has either being successfully sent (in the case of SendingResult::Sent) or its sending has failed (any other SendingResult variant.)